#ifndef _DDR3_MAP_H_
#define _DDR3_MAP_H_

#include "acq_chan.h"
#include "varg_macros.h"

/* Does the acquisition channel gets a memory region? */
#define DDR3_MEM_BOOL(MEM_SIZE)         IF(MEM_SIZE > 0)(1, 0)

/* Start of the acquisition memory address */
#define DDR3_ACQ_START_ADDR             0x0

/* Dummy region
 * Size: 0 DDR3 regions */
#define DDR3_DUMMY_INIT0_SAMPLE_SIZE    0
#define DDR3_DUMMY_INIT0_MEM_SIZE       0

#define DDR3_DUMMY_INIT0_MEM_BOOL       DDR3_MEM_BOOL(DDR3_DUMMY_INIT0_MEM_SIZE)
#define DDR3_DUMMY_INIT0_START_ADDR     DDR3_ACQ_START_ADDR
#define DDR3_DUMMY_INIT0_END_ADDR       (DDR3_DUMMY_INIT0_START_ADDR + DDR3_DUMMY_INIT0_MEM_SIZE*MEM_REGION_SIZE)
#define DDR3_DUMMY_INIT0_MAX_SAMPLES    (DDR3_DUMMY_INIT0_END_ADDR-DDR3_DUMMY_INIT0_START_ADDR)

/************************ Acquistion 0 Channel Parameters **************/

/* ADC 0 (shares the same memory space as the ADCSWAP0)
 * Size: 2 DDR3 regions */
#define DDR3_ADC0_SAMPLE_SIZE           ADC0_SAMPLE_SIZE
#define DDR3_ADC0_MEM_SIZE              2

#define DDR3_ADC0_MEM_BOOL              DDR3_MEM_BOOL(DDR3_ADC0_MEM_SIZE)
#define DDR3_ADC0_START_ADDR            (DDR3_DUMMY_INIT0_START_ADDR + DDR3_DUMMY_INIT0_MEM_BOOL*DDR3_DUMMY_INIT0_SAMPLE_SIZE)
#define DDR3_ADC0_END_ADDR              (DDR3_ADC0_START_ADDR + DDR3_ADC0_MEM_SIZE*MEM_REGION_SIZE - DDR3_ADC0_MEM_BOOL*DDR3_ADC0_SAMPLE_SIZE)
#define DDR3_ADC0_MAX_SAMPLES           ((DDR3_ADC0_END_ADDR-DDR3_ADC0_START_ADDR) / DDR3_ADC0_SAMPLE_SIZE)

/* ADCSWAP 0 (shares the same memory space as the ADC0)
 * Size: 2 DDR3 regions */
#define DDR3_ADCSWAP0_SAMPLE_SIZE       ADCSWAP0_SAMPLE_SIZE
#define DDR3_ADCSWAP0_MEM_SIZE          2

#define DDR3_ADCSWAP0_MEM_BOOL          DDR3_MEM_BOOL(DDR3_ADCSWAP0_MEM_SIZE)
#define DDR3_ADCSWAP0_START_ADDR        (DDR3_DUMMY_INIT0_START_ADDR + DDR3_DUMMY_INIT0_MEM_BOOL*DDR3_DUMMY_INIT0_SAMPLE_SIZE)
#define DDR3_ADCSWAP0_END_ADDR          (DDR3_ADCSWAP0_START_ADDR + DDR3_ADCSWAP0_MEM_SIZE*MEM_REGION_SIZE - DDR3_ADCSWAP0_MEM_BOOL*DDR3_ADCSWAP0_SAMPLE_SIZE)
#define DDR3_ADCSWAP0_MAX_SAMPLES       ((DDR3_ADCSWAP0_END_ADDR-DDR3_ADCSWAP0_START_ADDR) / DDR3_ADCSWAP0_SAMPLE_SIZE)

/* MIXER I/Q 1/2 (shares the same memory space as the MIXIQ340)
 * Size: 1 DDR3 regions */
#define DDR3_MIXIQ120_SAMPLE_SIZE       MIXIQ120_SAMPLE_SIZE
#define DDR3_MIXIQ120_MEM_SIZE          1

#define DDR3_MIXIQ120_MEM_BOOL          DDR3_MEM_BOOL(DDR3_MIXIQ120_MEM_SIZE)
#define DDR3_MIXIQ120_START_ADDR        (DDR3_ADCSWAP0_END_ADDR + DDR3_ADCSWAP0_MEM_BOOL*DDR3_ADCSWAP0_SAMPLE_SIZE)
#define DDR3_MIXIQ120_END_ADDR          (DDR3_MIXIQ120_START_ADDR + DDR3_MIXIQ120_MEM_SIZE*MEM_REGION_SIZE - DDR3_MIXIQ120_MEM_BOOL*DDR3_MIXIQ120_SAMPLE_SIZE)
#define DDR3_MIXIQ120_MAX_SAMPLES       ((DDR3_MIXIQ120_END_ADDR-DDR3_MIXIQ120_START_ADDR) / DDR3_MIXIQ120_SAMPLE_SIZE)

/* MIXER I/Q 3/4 (shares the same memory space as the MIXIQ120)
 * Size: 1 DDR3 regions */
#define DDR3_MIXIQ340_SAMPLE_SIZE       MIXIQ340_SAMPLE_SIZE
#define DDR3_MIXIQ340_MEM_SIZE          1

#define DDR3_MIXIQ340_MEM_BOOL          DDR3_MEM_BOOL(DDR3_MIXIQ340_MEM_SIZE)
#define DDR3_MIXIQ340_START_ADDR        (DDR3_ADCSWAP0_END_ADDR + DDR3_ADCSWAP0_MEM_BOOL*DDR3_ADCSWAP0_SAMPLE_SIZE)
#define DDR3_MIXIQ340_END_ADDR          (DDR3_MIXIQ340_START_ADDR + DDR3_MIXIQ340_MEM_SIZE*MEM_REGION_SIZE - DDR3_MIXIQ340_MEM_BOOL*DDR3_MIXIQ340_SAMPLE_SIZE)
#define DDR3_MIXIQ340_MAX_SAMPLES       ((DDR3_MIXIQ340_END_ADDR-DDR3_MIXIQ340_START_ADDR) / DDR3_MIXIQ340_SAMPLE_SIZE)

/* TBTDECIM I/Q 1/2 (shares the same memory space as the TBTDECIMIQ340 and TBTAMP0)
 * Size: 1 DDR3 regions */
#define DDR3_TBTDECIMIQ120_SAMPLE_SIZE  TBTDECIMIQ120_SAMPLE_SIZE
#define DDR3_TBTDECIMIQ120_MEM_SIZE     2

#define DDR3_TBTDECIMIQ120_MEM_BOOL     DDR3_MEM_BOOL(DDR3_TBTDECIMIQ120_MEM_SIZE)
#define DDR3_TBTDECIMIQ120_START_ADDR   (DDR3_MIXIQ340_END_ADDR + DDR3_MIXIQ340_MEM_BOOL*DDR3_MIXIQ340_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ120_END_ADDR     (DDR3_TBTDECIMIQ120_START_ADDR + DDR3_TBTDECIMIQ120_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTDECIMIQ120_MEM_BOOL*DDR3_TBTDECIMIQ120_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ120_MAX_SAMPLES  ((DDR3_TBTDECIMIQ120_END_ADDR-DDR3_TBTDECIMIQ120_START_ADDR) / DDR3_TBTDECIMIQ120_SAMPLE_SIZE)

/* TBTDECIM I/Q 3/4 (shares the same memory space as the TBTDECIMIQ120 and TBTAMP0)
 * Size: 1 DDR3 regions */
#define DDR3_TBTDECIMIQ340_SAMPLE_SIZE  TBTDECIMIQ340_SAMPLE_SIZE
#define DDR3_TBTDECIMIQ340_MEM_SIZE     2

#define DDR3_TBTDECIMIQ340_MEM_BOOL     DDR3_MEM_BOOL(DDR3_TBTDECIMIQ340_MEM_SIZE)
#define DDR3_TBTDECIMIQ340_START_ADDR   (DDR3_MIXIQ340_END_ADDR + DDR3_MIXIQ340_MEM_BOOL*DDR3_MIXIQ340_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ340_END_ADDR     (DDR3_TBTDECIMIQ340_START_ADDR + DDR3_TBTDECIMIQ340_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTDECIMIQ340_MEM_BOOL*DDR3_TBTDECIMIQ340_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ340_MAX_SAMPLES  ((DDR3_TBTDECIMIQ340_END_ADDR-DDR3_TBTDECIMIQ340_START_ADDR) / DDR3_TBTDECIMIQ340_SAMPLE_SIZE)

/* TBT 0 AMP (shares the same memory space as the TBTDECIMIQ120 and TBTDECIMIQ340)
 * Size: 2 DDR3 regions */
#define DDR3_TBTAMP0_SAMPLE_SIZE        TBTAMP0_SAMPLE_SIZE
#define DDR3_TBTAMP0_MEM_SIZE           2

#define DDR3_TBTAMP0_MEM_BOOL           DDR3_MEM_BOOL(DDR3_TBTAMP0_MEM_SIZE)
#define DDR3_TBTAMP0_START_ADDR         (DDR3_MIXIQ340_END_ADDR + DDR3_MIXIQ340_MEM_BOOL*DDR3_MIXIQ340_SAMPLE_SIZE)
#define DDR3_TBTAMP0_END_ADDR           (DDR3_TBTAMP0_START_ADDR + DDR3_TBTAMP0_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTAMP0_MEM_BOOL*DDR3_TBTAMP0_SAMPLE_SIZE)
#define DDR3_TBTAMP0_MAX_SAMPLES        ((DDR3_TBTAMP0_END_ADDR-DDR3_TBTAMP0_START_ADDR) / DDR3_TBTAMP0_SAMPLE_SIZE)

/* TBT 0 PHA (shares the same memory space as the TBTDECIMIQ120 and TBTDECIMIQ340)
 * Size: 2 DDR3 regions */
#define DDR3_TBTPHA0_SAMPLE_SIZE        TBTPHA0_SAMPLE_SIZE
#define DDR3_TBTPHA0_MEM_SIZE           2

#define DDR3_TBTPHA0_MEM_BOOL           DDR3_MEM_BOOL(DDR3_TBTPHA0_MEM_SIZE)
#define DDR3_TBTPHA0_START_ADDR         (DDR3_MIXIQ340_END_ADDR + DDR3_MIXIQ340_MEM_BOOL*DDR3_MIXIQ340_SAMPLE_SIZE)
#define DDR3_TBTPHA0_END_ADDR           (DDR3_TBTPHA0_START_ADDR + DDR3_TBTPHA0_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTPHA0_MEM_BOOL*DDR3_TBTPHA0_SAMPLE_SIZE)
#define DDR3_TBTPHA0_MAX_SAMPLES        ((DDR3_TBTPHA0_END_ADDR-DDR3_TBTPHA0_START_ADDR) / DDR3_TBTPHA0_SAMPLE_SIZE)

/* TBT 0 POS (shares the same memory space as the TBTDECIMIQ120 and TBTDECIMIQ340)
 * Size: 0 DDR3 regions */
#define DDR3_TBTPOS0_SAMPLE_SIZE        TBTPOS0_SAMPLE_SIZE
#define DDR3_TBTPOS0_MEM_SIZE           2

#define DDR3_TBTPOS0_MEM_BOOL           DDR3_MEM_BOOL(DDR3_TBTPOS0_MEM_SIZE)
#define DDR3_TBTPOS0_START_ADDR         (DDR3_MIXIQ340_END_ADDR + DDR3_MIXIQ340_MEM_BOOL*DDR3_MIXIQ340_SAMPLE_SIZE)
#define DDR3_TBTPOS0_END_ADDR           (DDR3_TBTPOS0_START_ADDR + DDR3_TBTPOS0_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTPOS0_MEM_BOOL*DDR3_TBTPOS0_SAMPLE_SIZE)
#define DDR3_TBTPOS0_MAX_SAMPLES        ((DDR3_TBTPOS0_END_ADDR-DDR3_TBTPOS0_START_ADDR) / DDR3_TBTPOS0_SAMPLE_SIZE)

/* FOFBDECIM I/Q 1/2 (shares the same memory space as the FOFBDECIMIQ340 and FOFBAMP0)
 * Size: 1 DDR3 regions */
#define DDR3_FOFBDECIMIQ120_SAMPLE_SIZE FOFBDECIMIQ120_SAMPLE_SIZE
#define DDR3_FOFBDECIMIQ120_MEM_SIZE    2

#define DDR3_FOFBDECIMIQ120_MEM_BOOL    DDR3_MEM_BOOL(DDR3_FOFBDECIMIQ120_MEM_SIZE)
#define DDR3_FOFBDECIMIQ120_START_ADDR  (DDR3_TBTPOS0_END_ADDR + DDR3_TBTPOS0_MEM_BOOL*DDR3_TBTPOS0_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ120_END_ADDR    (DDR3_FOFBDECIMIQ120_START_ADDR + DDR3_FOFBDECIMIQ120_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBDECIMIQ120_MEM_BOOL*DDR3_FOFBDECIMIQ120_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ120_MAX_SAMPLES ((DDR3_FOFBDECIMIQ120_END_ADDR-DDR3_FOFBDECIMIQ120_START_ADDR) / DDR3_FOFBDECIMIQ120_SAMPLE_SIZE)

/* FOFBDECIM I/Q 3/4 (shares the same memory space as the FOFBDECIMIQ120 and FOFBAMP0)
 * Size: 1 DDR3 regions */
#define DDR3_FOFBDECIMIQ340_SAMPLE_SIZE FOFBDECIMIQ340_SAMPLE_SIZE
#define DDR3_FOFBDECIMIQ340_MEM_SIZE    2

#define DDR3_FOFBDECIMIQ340_MEM_BOOL    DDR3_MEM_BOOL(DDR3_FOFBDECIMIQ340_MEM_SIZE)
#define DDR3_FOFBDECIMIQ340_START_ADDR  (DDR3_TBTPOS0_END_ADDR + DDR3_TBTPOS0_MEM_BOOL*DDR3_TBTPOS0_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ340_END_ADDR    (DDR3_FOFBDECIMIQ340_START_ADDR + DDR3_FOFBDECIMIQ340_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBDECIMIQ340_MEM_BOOL*DDR3_FOFBDECIMIQ340_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ340_MAX_SAMPLES ((DDR3_FOFBDECIMIQ340_END_ADDR-DDR3_FOFBDECIMIQ340_START_ADDR) / DDR3_FOFBDECIMIQ340_SAMPLE_SIZE)

/* FOFB 0 AMP
 * Size: 2 DDR3 regions */
#define DDR3_FOFBAMP0_SAMPLE_SIZE       FOFBAMP0_SAMPLE_SIZE
#define DDR3_FOFBAMP0_MEM_SIZE          2

#define DDR3_FOFBAMP0_MEM_BOOL          DDR3_MEM_BOOL(DDR3_FOFBAMP0_MEM_SIZE)
#define DDR3_FOFBAMP0_START_ADDR        (DDR3_TBTPOS0_END_ADDR + DDR3_TBTPOS0_MEM_BOOL*DDR3_TBTPOS0_SAMPLE_SIZE)
#define DDR3_FOFBAMP0_END_ADDR          (DDR3_FOFBAMP0_START_ADDR + DDR3_FOFBAMP0_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBAMP0_MEM_BOOL*DDR3_FOFBAMP0_SAMPLE_SIZE)
#define DDR3_FOFBAMP0_MAX_SAMPLES       ((DDR3_FOFBAMP0_END_ADDR-DDR3_FOFBAMP0_START_ADDR) / DDR3_FOFBAMP0_SAMPLE_SIZE)

/* FOFB 0 PHA (shares the same memory space as the FOFBDECIMIQ12 and FOFBDECIMIQ34)
 * Size: 2 DDR3 regions */
#define DDR3_FOFBPHA0_SAMPLE_SIZE       FOFBPHA0_SAMPLE_SIZE
#define DDR3_FOFBPHA0_MEM_SIZE          2

#define DDR3_FOFBPHA0_MEM_BOOL          DDR3_MEM_BOOL(DDR3_FOFBPHA0_MEM_SIZE)
#define DDR3_FOFBPHA0_START_ADDR        (DDR3_TBTPOS0_END_ADDR + DDR3_TBTPOS0_MEM_BOOL*DDR3_TBTPOS0_SAMPLE_SIZE)
#define DDR3_FOFBPHA0_END_ADDR          (DDR3_FOFBPHA0_START_ADDR + DDR3_FOFBPHA0_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBPHA0_MEM_BOOL*DDR3_FOFBPHA0_SAMPLE_SIZE)
#define DDR3_FOFBPHA0_MAX_SAMPLES       ((DDR3_FOFBPHA0_END_ADDR-DDR3_FOFBPHA0_START_ADDR) / DDR3_FOFBPHA0_SAMPLE_SIZE)

/* FOFB 0 POS
 * Size: 0 DDR3 regions */
#define DDR3_FOFBPOS0_SAMPLE_SIZE       FOFBPOS0_SAMPLE_SIZE
#define DDR3_FOFBPOS0_MEM_SIZE          2

#define DDR3_FOFBPOS0_MEM_BOOL          DDR3_MEM_BOOL(DDR3_FOFBPOS0_MEM_SIZE)
#define DDR3_FOFBPOS0_START_ADDR        (DDR3_TBTPOS0_END_ADDR + DDR3_TBTPOS0_MEM_BOOL*DDR3_TBTPOS0_SAMPLE_SIZE)
#define DDR3_FOFBPOS0_END_ADDR          (DDR3_FOFBPOS0_START_ADDR + DDR3_FOFBPOS0_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBPOS0_MEM_BOOL*DDR3_FOFBPOS0_SAMPLE_SIZE)
#define DDR3_FOFBPOS0_MAX_SAMPLES       ((DDR3_FOFBPOS0_END_ADDR-DDR3_FOFBPOS0_START_ADDR) / DDR3_FOFBPOS0_SAMPLE_SIZE)

 /* MONIT 0 AMP
 * Size: 0 DDR3 regions */
#define DDR3_MONITAMP0_SAMPLE_SIZE      MONITAMP0_SAMPLE_SIZE
#define DDR3_MONITAMP0_MEM_SIZE         0

#define DDR3_MONITAMP0_MEM_BOOL         DDR3_MEM_BOOL(DDR3_MONITAMP0_MEM_SIZE)
#define DDR3_MONITAMP0_START_ADDR       (DDR3_FOFBPOS0_END_ADDR + DDR3_FOFBPOS0_MEM_BOOL*DDR3_FOFBPOS0_SAMPLE_SIZE)
#define DDR3_MONITAMP0_END_ADDR         (DDR3_MONITAMP0_START_ADDR + DDR3_MONITAMP0_MEM_SIZE*MEM_REGION_SIZE - DDR3_MONITAMP0_MEM_BOOL*DDR3_MONITAMP0_SAMPLE_SIZE)
#define DDR3_MONITAMP0_MAX_SAMPLES      ((DDR3_MONITAMP0_END_ADDR-DDR3_MONITAMP0_START_ADDR) / DDR3_MONITAMP0_SAMPLE_SIZE)

/* MONIT 0 POS
 * Size: 0 DDR3 regions */
#define DDR3_MONITPOS0_SAMPLE_SIZE      MONITPOS0_SAMPLE_SIZE
#define DDR3_MONITPOS0_MEM_SIZE         0

#define DDR3_MONITPOS0_MEM_BOOL         DDR3_MEM_BOOL(DDR3_MONITPOS0_MEM_SIZE)
#define DDR3_MONITPOS0_START_ADDR       (DDR3_MONITAMP0_END_ADDR + DDR3_MONITAMP0_MEM_BOOL*DDR3_MONITAMP0_SAMPLE_SIZE)
#define DDR3_MONITPOS0_END_ADDR         (DDR3_MONITPOS0_START_ADDR + DDR3_MONITPOS0_MEM_SIZE*MEM_REGION_SIZE - DDR3_MONITPOS0_MEM_BOOL*DDR3_MONITPOS0_SAMPLE_SIZE)
#define DDR3_MONITPOS0_MAX_SAMPLES      ((DDR3_MONITPOS0_END_ADDR-DDR3_MONITPOS0_START_ADDR) / DDR3_MONITPOS0_SAMPLE_SIZE)

/* MONIT1 0 POS
 * Size: 0 DDR3 regions */
#define DDR3_MONIT1POS0_SAMPLE_SIZE     MONIT1POS0_SAMPLE_SIZE
#define DDR3_MONIT1POS0_MEM_SIZE        0

#define DDR3_MONIT1POS0_MEM_BOOL        DDR3_MEM_BOOL(DDR3_MONIT1POS0_MEM_SIZE)
#define DDR3_MONIT1POS0_START_ADDR      (DDR3_MONITPOS0_END_ADDR + DDR3_MONITPOS0_MEM_BOOL*DDR3_MONITPOS0_SAMPLE_SIZE)
#define DDR3_MONIT1POS0_END_ADDR        (DDR3_MONIT1POS0_START_ADDR + DDR3_MONIT1POS0_MEM_SIZE*MEM_REGION_SIZE - DDR3_MONIT1POS0_MEM_BOOL*DDR3_MONIT1POS0_SAMPLE_SIZE)
#define DDR3_MONIT1POS0_MAX_SAMPLES     ((DDR3_MONIT1POS0_END_ADDR-DDR3_MONIT1POS0_START_ADDR) / DDR3_MONIT1POS0_SAMPLE_SIZE)

/* End 0 Dummy region
 * Size: 0 DDR3 regions */
#define DDR3_DUMMY_END0_SAMPLE_SIZE     MONIT1POS0_SAMPLE_SIZE
#define DDR3_DUMMY_END0_MEM_SIZE        0

#define DDR3_DUMMY_END0_MEM_BOOL        DDR3_MEM_BOOL(DDR3_DUMMY_END0_MEM_SIZE)
#define DDR3_DUMMY_END0_START_ADDR      DDR3_MONIT1POS0_END_ADDR
#define DDR3_DUMMY_END0_END_ADDR        (DDR3_DUMMY_END0_START_ADDR + DDR3_DUMMY_END0_MEM_SIZE*MEM_REGION_SIZE)
#define DDR3_DUMMY_END0_MAX_SAMPLES     (DDR3_DUMMY_END0_END_ADDR-DDR3_DUMMY_END0_START_ADDR)

/************************ Acquistion 1 Channel Parameters **************/

/* ADC 1
 * Size: 2 DDR3 regions */
#define DDR3_ADC1_SAMPLE_SIZE           ADC0_SAMPLE_SIZE
#define DDR3_ADC1_MEM_SIZE              2

#define DDR3_ADC1_MEM_BOOL              DDR3_MEM_BOOL(DDR3_ADC1_MEM_SIZE)
#define DDR3_ADC1_START_ADDR            (DDR3_DUMMY_END0_START_ADDR + DDR3_DUMMY_END0_MEM_BOOL*DDR3_DUMMY_END0_SAMPLE_SIZE)
#define DDR3_ADC1_END_ADDR              (DDR3_ADC1_START_ADDR + DDR3_ADC1_MEM_SIZE*MEM_REGION_SIZE - DDR3_ADC1_MEM_BOOL*DDR3_ADC1_SAMPLE_SIZE)
#define DDR3_ADC1_MAX_SAMPLES           ((DDR3_ADC1_END_ADDR-DDR3_ADC1_START_ADDR) / DDR3_ADC1_SAMPLE_SIZE)

/* ADCSWAP 1
 * Size: 2 DDR3 regions */
#define DDR3_ADCSWAP1_SAMPLE_SIZE       ADCSWAP0_SAMPLE_SIZE
#define DDR3_ADCSWAP1_MEM_SIZE          2

#define DDR3_ADCSWAP1_MEM_BOOL          DDR3_MEM_BOOL(DDR3_ADCSWAP1_MEM_SIZE)
#define DDR3_ADCSWAP1_START_ADDR        (DDR3_DUMMY_END0_START_ADDR + DDR3_DUMMY_END0_MEM_BOOL*DDR3_DUMMY_END0_SAMPLE_SIZE)
#define DDR3_ADCSWAP1_END_ADDR          (DDR3_ADCSWAP1_START_ADDR + DDR3_ADCSWAP1_MEM_SIZE*MEM_REGION_SIZE - DDR3_ADCSWAP1_MEM_BOOL*DDR3_ADCSWAP1_SAMPLE_SIZE)
#define DDR3_ADCSWAP1_MAX_SAMPLES       ((DDR3_ADCSWAP1_END_ADDR-DDR3_ADCSWAP1_START_ADDR) / DDR3_ADCSWAP1_SAMPLE_SIZE)

/* MIXER I/Q 1/2 (shares the same memory space as the MIXIQ341)
 * Size: 1 DDR3 regions */
#define DDR3_MIXIQ121_SAMPLE_SIZE       MIXIQ120_SAMPLE_SIZE
#define DDR3_MIXIQ121_MEM_SIZE          1

#define DDR3_MIXIQ121_MEM_BOOL          DDR3_MEM_BOOL(DDR3_MIXIQ121_MEM_SIZE)
#define DDR3_MIXIQ121_START_ADDR        (DDR3_ADCSWAP1_END_ADDR + DDR3_ADCSWAP0_MEM_BOOL*DDR3_ADCSWAP0_SAMPLE_SIZE)
#define DDR3_MIXIQ121_END_ADDR          (DDR3_MIXIQ121_START_ADDR + DDR3_MIXIQ121_MEM_SIZE*MEM_REGION_SIZE - DDR3_MIXIQ121_MEM_BOOL*DDR3_MIXIQ121_SAMPLE_SIZE)
#define DDR3_MIXIQ121_MAX_SAMPLES       ((DDR3_MIXIQ121_END_ADDR-DDR3_MIXIQ121_START_ADDR) / DDR3_MIXIQ121_SAMPLE_SIZE)

/* MIXER I/Q 3/4 (shares the same memory space as the MIXIQ121)
 * Size: 1 DDR3 regions */
#define DDR3_MIXIQ341_SAMPLE_SIZE       MIXIQ340_SAMPLE_SIZE
#define DDR3_MIXIQ341_MEM_SIZE          1

#define DDR3_MIXIQ341_MEM_BOOL          DDR3_MEM_BOOL(DDR3_MIXIQ341_MEM_SIZE)
#define DDR3_MIXIQ341_START_ADDR        (DDR3_ADCSWAP1_END_ADDR + DDR3_ADCSWAP0_MEM_BOOL*DDR3_ADCSWAP0_SAMPLE_SIZE)
#define DDR3_MIXIQ341_END_ADDR          (DDR3_MIXIQ341_START_ADDR + DDR3_MIXIQ341_MEM_SIZE*MEM_REGION_SIZE - DDR3_MIXIQ341_MEM_BOOL*DDR3_MIXIQ341_SAMPLE_SIZE)
#define DDR3_MIXIQ341_MAX_SAMPLES       ((DDR3_MIXIQ341_END_ADDR-DDR3_MIXIQ341_START_ADDR) / DDR3_MIXIQ341_SAMPLE_SIZE)

/* TBTDECIM I/Q 1/2 (shares the same memory space as the TBTDECIMIQ341 and TBTAMP1)
 * Size: 1 DDR3 regions */
#define DDR3_TBTDECIMIQ121_SAMPLE_SIZE  TBTDECIMIQ120_SAMPLE_SIZE
#define DDR3_TBTDECIMIQ121_MEM_SIZE     2

#define DDR3_TBTDECIMIQ121_MEM_BOOL     DDR3_MEM_BOOL(DDR3_TBTDECIMIQ121_MEM_SIZE)
#define DDR3_TBTDECIMIQ121_START_ADDR   (DDR3_MIXIQ341_END_ADDR + DDR3_MIXIQ341_MEM_BOOL*DDR3_MIXIQ341_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ121_END_ADDR     (DDR3_TBTDECIMIQ121_START_ADDR + DDR3_TBTDECIMIQ121_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTDECIMIQ121_MEM_BOOL*DDR3_TBTDECIMIQ121_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ121_MAX_SAMPLES  ((DDR3_TBTDECIMIQ121_END_ADDR-DDR3_TBTDECIMIQ121_START_ADDR) / DDR3_TBTDECIMIQ121_SAMPLE_SIZE)

/* TBTDECIM I/Q 3/4 (shares the same memory space as the TBTDECIMIQ121 and TBTAMP1)
 * Size: 1 DDR3 regions */
#define DDR3_TBTDECIMIQ341_SAMPLE_SIZE  TBTDECIMIQ340_SAMPLE_SIZE
#define DDR3_TBTDECIMIQ341_MEM_SIZE     2

#define DDR3_TBTDECIMIQ341_MEM_BOOL     DDR3_MEM_BOOL(DDR3_TBTDECIMIQ341_MEM_SIZE)
#define DDR3_TBTDECIMIQ341_START_ADDR   (DDR3_MIXIQ341_END_ADDR + DDR3_MIXIQ341_MEM_BOOL*DDR3_MIXIQ341_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ341_END_ADDR     (DDR3_TBTDECIMIQ341_START_ADDR + DDR3_TBTDECIMIQ341_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTDECIMIQ341_MEM_BOOL*DDR3_TBTDECIMIQ341_SAMPLE_SIZE)
#define DDR3_TBTDECIMIQ341_MAX_SAMPLES  ((DDR3_TBTDECIMIQ341_END_ADDR-DDR3_TBTDECIMIQ341_START_ADDR) / DDR3_TBTDECIMIQ341_SAMPLE_SIZE)

/* TBT 1 AMP
 * Size: 2 DDR3 regions */
#define DDR3_TBTAMP1_SAMPLE_SIZE        TBTAMP0_SAMPLE_SIZE
#define DDR3_TBTAMP1_MEM_SIZE           2

#define DDR3_TBTAMP1_MEM_BOOL           DDR3_MEM_BOOL(DDR3_TBTAMP1_MEM_SIZE)
#define DDR3_TBTAMP1_START_ADDR         (DDR3_MIXIQ341_END_ADDR + DDR3_MIXIQ341_MEM_BOOL*DDR3_MIXIQ341_SAMPLE_SIZE)
#define DDR3_TBTAMP1_END_ADDR           (DDR3_TBTAMP1_START_ADDR + DDR3_TBTAMP1_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTAMP1_MEM_BOOL*DDR3_TBTAMP1_SAMPLE_SIZE)
#define DDR3_TBTAMP1_MAX_SAMPLES        ((DDR3_TBTAMP1_END_ADDR-DDR3_TBTAMP1_START_ADDR) / DDR3_TBTAMP1_SAMPLE_SIZE)

/* TBT 1 PHA (shares the same memory space as the TBTDECIMIQ121 and TBTDECIMIQ341)
 * Size: 2 DDR3 regions */
#define DDR3_TBTPHA1_SAMPLE_SIZE        TBTPHA0_SAMPLE_SIZE
#define DDR3_TBTPHA1_MEM_SIZE           2

#define DDR3_TBTPHA1_MEM_BOOL           DDR3_MEM_BOOL(DDR3_TBTPHA1_MEM_SIZE)
#define DDR3_TBTPHA1_START_ADDR         (DDR3_MIXIQ341_END_ADDR + DDR3_MIXIQ341_MEM_BOOL*DDR3_MIXIQ341_SAMPLE_SIZE)
#define DDR3_TBTPHA1_END_ADDR           (DDR3_TBTPHA1_START_ADDR + DDR3_TBTPHA1_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTPHA1_MEM_BOOL*DDR3_TBTPHA1_SAMPLE_SIZE)
#define DDR3_TBTPHA1_MAX_SAMPLES        ((DDR3_TBTPHA1_END_ADDR-DDR3_TBTPHA1_START_ADDR) / DDR3_TBTPHA1_SAMPLE_SIZE)

/* TBT 1 POS
 * Size: 1 DDR3 regions */
#define DDR3_TBTPOS1_SAMPLE_SIZE        TBTPOS0_SAMPLE_SIZE
#define DDR3_TBTPOS1_MEM_SIZE           2

#define DDR3_TBTPOS1_MEM_BOOL           DDR3_MEM_BOOL(DDR3_TBTPOS1_MEM_SIZE)
#define DDR3_TBTPOS1_START_ADDR         (DDR3_MIXIQ341_END_ADDR + DDR3_MIXIQ341_MEM_BOOL*DDR3_MIXIQ341_SAMPLE_SIZE)
#define DDR3_TBTPOS1_END_ADDR           (DDR3_TBTPOS1_START_ADDR + DDR3_TBTPOS1_MEM_SIZE*MEM_REGION_SIZE - DDR3_TBTPOS1_MEM_BOOL*DDR3_TBTPOS1_SAMPLE_SIZE)
#define DDR3_TBTPOS1_MAX_SAMPLES        ((DDR3_TBTPOS1_END_ADDR-DDR3_TBTPOS1_START_ADDR) / DDR3_TBTPOS1_SAMPLE_SIZE)

/* FOFBDECIM I/Q 1/2 (shares the same memory space as the FOFBDECIMIQ341 and FOFBAMP1)
 * Size: 1 DDR3 regions */
#define DDR3_FOFBDECIMIQ121_SAMPLE_SIZE FOFBDECIMIQ120_SAMPLE_SIZE
#define DDR3_FOFBDECIMIQ121_MEM_SIZE    2

#define DDR3_FOFBDECIMIQ121_MEM_BOOL    DDR3_MEM_BOOL(DDR3_FOFBDECIMIQ121_MEM_SIZE)
#define DDR3_FOFBDECIMIQ121_START_ADDR  (DDR3_TBTPOS1_END_ADDR + DDR3_TBTPOS1_MEM_BOOL*DDR3_TBTPOS1_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ121_END_ADDR    (DDR3_FOFBDECIMIQ121_START_ADDR + DDR3_FOFBDECIMIQ121_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBDECIMIQ121_MEM_BOOL*DDR3_FOFBDECIMIQ121_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ121_MAX_SAMPLES ((DDR3_FOFBDECIMIQ121_END_ADDR-DDR3_FOFBDECIMIQ121_START_ADDR) / DDR3_FOFBDECIMIQ121_SAMPLE_SIZE)

/* FOFBDECIM I/Q 3/4 (shares the same memory space as the FOFBDECIMIQ121 and FOFBAMP1)
 * Size: 1 DDR3 regions */
#define DDR3_FOFBDECIMIQ341_SAMPLE_SIZE FOFBDECIMIQ340_SAMPLE_SIZE
#define DDR3_FOFBDECIMIQ341_MEM_SIZE    2

#define DDR3_FOFBDECIMIQ341_MEM_BOOL    DDR3_MEM_BOOL(DDR3_FOFBDECIMIQ341_MEM_SIZE)
#define DDR3_FOFBDECIMIQ341_START_ADDR  (DDR3_TBTPOS1_END_ADDR + DDR3_TBTPOS1_MEM_BOOL*DDR3_TBTPOS1_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ341_END_ADDR    (DDR3_FOFBDECIMIQ341_START_ADDR + DDR3_FOFBDECIMIQ341_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBDECIMIQ341_MEM_BOOL*DDR3_FOFBDECIMIQ341_SAMPLE_SIZE)
#define DDR3_FOFBDECIMIQ341_MAX_SAMPLES ((DDR3_FOFBDECIMIQ341_END_ADDR-DDR3_FOFBDECIMIQ341_START_ADDR) / DDR3_FOFBDECIMIQ341_SAMPLE_SIZE)

/* FOFB 1 AMP
 * Size: 2 DDR3 regions */
#define DDR3_FOFBAMP1_SAMPLE_SIZE       FOFBAMP0_SAMPLE_SIZE
#define DDR3_FOFBAMP1_MEM_SIZE          2

#define DDR3_FOFBAMP1_MEM_BOOL          DDR3_MEM_BOOL(DDR3_FOFBAMP1_MEM_SIZE)
#define DDR3_FOFBAMP1_START_ADDR        (DDR3_TBTPOS1_END_ADDR + DDR3_TBTPOS1_MEM_BOOL*DDR3_TBTPOS1_SAMPLE_SIZE)
#define DDR3_FOFBAMP1_END_ADDR          (DDR3_FOFBAMP1_START_ADDR + DDR3_FOFBAMP1_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBAMP1_MEM_BOOL*DDR3_FOFBAMP1_SAMPLE_SIZE)
#define DDR3_FOFBAMP1_MAX_SAMPLES       ((DDR3_FOFBAMP1_END_ADDR-DDR3_FOFBAMP1_START_ADDR) / DDR3_FOFBAMP1_SAMPLE_SIZE)

/* FOFB 1 PHA (shares the same memory space as the FOFBDECIMIQ121 and FOFBDECIMIQ341)
 * Size: 2 DDR3 regions */
#define DDR3_FOFBPHA1_SAMPLE_SIZE       FOFBPHA0_SAMPLE_SIZE
#define DDR3_FOFBPHA1_MEM_SIZE          2

#define DDR3_FOFBPHA1_MEM_BOOL          DDR3_MEM_BOOL(DDR3_FOFBPHA1_MEM_SIZE)
#define DDR3_FOFBPHA1_START_ADDR        (DDR3_TBTPOS1_END_ADDR + DDR3_TBTPOS1_MEM_BOOL*DDR3_TBTPOS1_SAMPLE_SIZE)
#define DDR3_FOFBPHA1_END_ADDR          (DDR3_FOFBPHA1_START_ADDR + DDR3_FOFBPHA1_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBPHA1_MEM_BOOL*DDR3_FOFBPHA1_SAMPLE_SIZE)
#define DDR3_FOFBPHA1_MAX_SAMPLES       ((DDR3_FOFBPHA1_END_ADDR-DDR3_FOFBPHA1_START_ADDR) / DDR3_FOFBPHA1_SAMPLE_SIZE)

/* FOFB 1 POS
 * Size: 1 DDR3 regions */
#define DDR3_FOFBPOS1_SAMPLE_SIZE       FOFBPOS0_SAMPLE_SIZE
#define DDR3_FOFBPOS1_MEM_SIZE          2

#define DDR3_FOFBPOS1_MEM_BOOL          DDR3_MEM_BOOL(DDR3_FOFBPOS1_MEM_SIZE)
#define DDR3_FOFBPOS1_START_ADDR        (DDR3_TBTPOS1_END_ADDR + DDR3_TBTPOS1_MEM_BOOL*DDR3_TBTPOS1_SAMPLE_SIZE)
#define DDR3_FOFBPOS1_END_ADDR          (DDR3_FOFBPOS1_START_ADDR + DDR3_FOFBPOS1_MEM_SIZE*MEM_REGION_SIZE - DDR3_FOFBPOS1_MEM_BOOL*DDR3_FOFBPOS1_SAMPLE_SIZE)
#define DDR3_FOFBPOS1_MAX_SAMPLES       ((DDR3_FOFBPOS1_END_ADDR-DDR3_FOFBPOS1_START_ADDR) / DDR3_FOFBPOS1_SAMPLE_SIZE)

 /* MONIT 1 AMP
 * Size: 1 DDR3 regions */
#define DDR3_MONITAMP1_SAMPLE_SIZE      MONITAMP0_SAMPLE_SIZE
#define DDR3_MONITAMP1_MEM_SIZE         0

#define DDR3_MONITAMP1_MEM_BOOL         DDR3_MEM_BOOL(DDR3_MONITAMP1_MEM_SIZE)
#define DDR3_MONITAMP1_START_ADDR       (DDR3_FOFBPOS1_END_ADDR + DDR3_FOFBPOS1_MEM_BOOL*DDR3_FOFBPOS1_SAMPLE_SIZE)
#define DDR3_MONITAMP1_END_ADDR         (DDR3_MONITAMP1_START_ADDR + DDR3_MONITAMP1_MEM_SIZE*MEM_REGION_SIZE - DDR3_MONITAMP1_MEM_BOOL*DDR3_MONITAMP1_SAMPLE_SIZE)
#define DDR3_MONITAMP1_MAX_SAMPLES      ((DDR3_MONITAMP1_END_ADDR-DDR3_MONITAMP1_START_ADDR) / DDR3_MONITAMP1_SAMPLE_SIZE)

/* MONIT 1 POS
 * Size: 1 DDR3 regions */
#define DDR3_MONITPOS1_SAMPLE_SIZE      MONITPOS0_SAMPLE_SIZE
#define DDR3_MONITPOS1_MEM_SIZE         0

#define DDR3_MONITPOS1_MEM_BOOL         DDR3_MEM_BOOL(DDR3_MONITPOS1_MEM_SIZE)
#define DDR3_MONITPOS1_START_ADDR       (DDR3_MONITAMP1_END_ADDR + DDR3_MONITAMP1_MEM_BOOL*DDR3_MONITAMP1_SAMPLE_SIZE)
#define DDR3_MONITPOS1_END_ADDR         (DDR3_MONITPOS1_START_ADDR + DDR3_MONITPOS1_MEM_SIZE*MEM_REGION_SIZE - DDR3_MONITPOS1_MEM_BOOL*DDR3_MONITPOS1_SAMPLE_SIZE)
#define DDR3_MONITPOS1_MAX_SAMPLES      ((DDR3_MONITPOS1_END_ADDR-DDR3_MONITPOS1_START_ADDR) / DDR3_MONITPOS1_SAMPLE_SIZE)

/* MONIT1 1 POS
 * Size: 1 DDR3 regions */
#define DDR3_MONIT1POS1_SAMPLE_SIZE     MONIT1POS0_SAMPLE_SIZE
#define DDR3_MONIT1POS1_MEM_SIZE        0

#define DDR3_MONIT1POS1_MEM_BOOL        DDR3_MEM_BOOL(DDR3_MONIT1POS1_MEM_SIZE)
#define DDR3_MONIT1POS1_START_ADDR      (DDR3_MONITPOS1_END_ADDR + DDR3_MONITPOS1_MEM_BOOL*DDR3_MONITPOS1_SAMPLE_SIZE)
#define DDR3_MONIT1POS1_END_ADDR        (DDR3_MONIT1POS1_START_ADDR + DDR3_MONIT1POS1_MEM_SIZE*MEM_REGION_SIZE - DDR3_MONIT1POS1_MEM_BOOL*DDR3_MONIT1POS1_SAMPLE_SIZE)
#define DDR3_MONIT1POS1_MAX_SAMPLES     ((DDR3_MONIT1POS1_END_ADDR-DDR3_MONIT1POS1_START_ADDR) / DDR3_MONIT1POS1_SAMPLE_SIZE)

/* End 1 Dummy region
 * Size: 0 DDR3 regions */
#define DDR3_DUMMY_END1_SAMPLE_SIZE     MONIT1POS0_SAMPLE_SIZE
#define DDR3_DUMMY_END1_MEM_SIZE        0

#define DDR3_DUMMY_END1_MEM_BOOL        DDR3_MEM_BOOL(DDR3_DUMMY_END1_MEM_SIZE)
#define DDR3_DUMMY_END1_START_ADDR      DDR3_MONIT1POS1_END_ADDR
#define DDR3_DUMMY_END1_END_ADDR        (DDR3_DUMMY_END1_START_ADDR + DDR3_DUMMY_END1_MEM_SIZE*MEM_REGION_SIZE)
#define DDR3_DUMMY_END1_MAX_SAMPLES     (DDR3_DUMMY_END1_END_ADDR-DDR3_DUMMY_END1_START_ADDR)

#endif

